@@ -271,6 +271,9 @@
 #define __NR_copy_file_range 285
 #define __NR_preadv2 286
 #define __NR_pwritev2 287
+#define __NR_pkey_mprotect 288
+#define __NR_pkey_alloc 289
+#define __NR_pkey_free 290
 
 #define SYS_io_setup 0
 #define SYS_io_destroy 1
@@ -545,3 +548,6 @@
 #define SYS_copy_file_range 285
 #define SYS_preadv2 286
 #define SYS_pwritev2 287
+#define SYS_pkey_mprotect 288
+#define SYS_pkey_alloc 289
+#define SYS_pkey_free 290
